/* ================== Doxygen Comment ======================================= */
/**
       \file
       \brief This module contains wrapper macros declarations 
              for safe memory management.

  TEAM_UNIQUE HEADER:

       Equipe Interaction Rayonnement Nuages - Laboratoire d'Optique Atmospherique
       Universite des Sciences et Technologies de Lille, Villeneuve d'Ascq

  PROGRAMMERS:

       Jerome Riedi  (jerome dot riedi at univ-lille1 dot fr)
       Francois Thieuleux (francois dot thieuleux at univ-lille1 dot fr)

  CORRESPONDING AUTHOR

       Jerome Riedi  (jerome dot riedi at univ-lille1 dot fr)

  REFERENCES AND CREDITS

       This work has been supported by USTL, CNRS and CNES.
       All credits go to Laboratoire d'Optique Atmospherique (USTL)

  COPYRIGHT (c) 2004-2012 by 

       Laboratoire d'Optique Atmospherique (UMR8518 CNRS/USTL)
       Batiment P5, USTL
       59 655 Villeneuve d'Ascq Cedex
       FRANCE
       http://www-loa.univ-lille1.fr

  LICENSE

       This program is free software; you can redistribute it and/or
       modify it under the terms of the GNU General Public License
       as published by the Free Software Foundation; either version 2
       of the License, or any later version.

       This program is distributed in the hope that it will be useful,
       but WITHOUT ANY WARRANTY; without even the implied warranty of
       MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
       GNU General Public License for more details.

       You should have received a copy of the GNU General Public License
       along with this program; if not, write to the Free Software Foundation,
       Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/
/* ================== Doxygen End Comment =================================== */
#ifndef H_COM_FCT_XALLOC_H
#define H_COM_FCT_XALLOC_H

#include <stdlib.h> /* malloc,... */

#include "com_fct_errors.h"

#ifdef DBG_SYSALLOC
#include "sysalloc.h"
#endif

/**
* @defgroup COM_FCT_xalloc  Module COM_FCT_xalloc
* \brief Commons macros for safe memory management
*/
//@{

/* ==== macros ============================================================== */
#define Malloc(ptr,size) \
do {\
  (ptr) = malloc( (size) );\
  if ( (ptr) == NULL)\
  {\
    fatal("Memory allocation (malloc)");\
  }\
} while(0)
                           

#define Calloc(ptr,nb,size) \
do {\
  (ptr) = calloc( (nb), (size) );\
  if ( (ptr) == NULL)\
  {\
    fatal("Memory allocation (calloc)");\
  }\
} while(0)
                           

#define Realloc(ptr,typ,nb) \
do {\
  (typ) * temp = NULL;\
  temp = realloc( (ptr), (nb) * sizeof( (typ) ) );\
  if ( temp == NULL)\
  {\
    free( (ptr) );\
    (ptr) = NULL;\
    fatal("Memory allocation (realloc)");\
  }\
  else\
  {\
    (ptr) = temp;\
  }\
} while(0)

                           
#define Free(ptr) \
do {\
  free( (ptr) );\
  (ptr) = NULL;\
} while(0)


/* ==== constants =========================================================== */
/* ==== types =============================================================== */
/* ==== structures ========================================================== */
/* ==== internal public functions =========================================== */
/* ==== entry points ======================================================== */
/* ==== public variables ==================================================== */
/* ==== inline public functions ============================================= */
//}@

#endif /* H_COM_FCT_XALLOC_H */
