/* 
 * caliop2ascii
 * Francois Thieuleux / Fabrice Ducos
 * Laboratoire d'Optique Atmospherique, 2007-2012
 */

#ifndef DEBUG_H
#define DEBUG_H

#include <stdio.h>
#include <assert.h>

#ifdef DEBUG
#define Debug(code) do { code } while (0)
#else
#define Debug(code)
#endif

#ifdef DEBUG
#define PDEBUG do { fprintf(stderr, "%s: %d: %s\n", __FILE__, __LINE__, __FUNCTION__); } while (0)
#else
#define PDEBUG
#endif

#ifdef DISABLE
#define Disable(code) do { } while (0)
#endif

#ifdef BENCH
#include <time.h>
#define Bench(code) \
do { \
  clock_t t0 = clock(); \
  code; \
  clock_t t1 = clock(); \
  double t01 = (t1 - t0)/((double) CLOCKS_PER_SEC); \
  fprintf(stderr,"%s: %d: %f s (%ld us)\n", __FILE__, __LINE__, t01, t1 - t0); \
  } while (0)
#else
#define Bench(code) do { code } while (0)
#endif

#endif /* DEBUG_H */
