/*---
 *
 * hdf_file
 *
 * Copyright (c) 2007-2012 by
 *
 * Francois Thieuleux (francois dot thieuleux at univ-lille1 dot fr)
 * Fabrice Ducos (fabrice dot ducos at univ-lille1 dot fr)
 * Jerome Riedi (jerome dot riedi at univ-lille1 dot fr)
 *
 * Laboratoire d'Optique Atmospherique
 *
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * ---*/

#ifndef HDF_FILE_H
#define HDF_FILE_H

/* */
#include <stdlib.h>
#include <stdio.h>
#include <math.h>
#include <string.h>  /* memset */
#include <strings.h> /* index, rindex */
#include <assert.h>
#include <libgen.h>  /* basename, dirname */

/* HDF includes */
#include <hdf.h>
#include <df.h>
#include <dfan.h>
#include <dfgr.h>
#include <dfi.h>
#include <dfrig.h>
#include <dfsd.h>
#include <mfhdf.h>
#include <hcomp.h>
#include <hntdefs.h>

#include "com_fct_errors.h"
#include "com_fct_xalloc.h"

typedef struct PTR_SDS
{
  char* name;
  void* data;
  int   rank;
  int   type;
  int   dimsizes[H4_MAX_VAR_DIMS];
  int   array_index[2];
  int   n_attrs;
} PTR_SDS;

/**/
#define NMAX_SDS 1024

#define BOUNDS_DISCONTINUE 1
#define BOUNDS_CONTINUE 2
#define BOUNDS_NLF 3

extern char SDS_names[NMAX_SDS][H4_MAX_NC_NAME];            /* Full list names of SDS available for the requested HDF input file */


/* Prototypes */
extern PTR_SDS* newPTR_SDSs(const char *file, int *sds_index_tab, int nb_sds);
extern void freePTR_SDSs(PTR_SDS* ptr_sds, int nb_sds);

extern int get_index_SDS(const char *SDSname, int nb_sds);
extern int get_array_bound_index_SDS(const char *SDSname, int array_index[]);
extern int get_arrays_bound_index_SDS(const char *SDSname, int array_index[]);
extern int get_list_SDSs(const char *file);
extern int print_list_SDSs(const char* file);

extern void display_fcf(const int j, PTR_SDS *ptr_sds, const int index_sds, const int language_offset, const unsigned char decode_fcf, const int index_array[],
                       char *output_line);

extern int get_hdf_file_nb_sds(const char *file);
extern int get_hdf_file_nb_nattr(const char *file);

extern const char *hdf_format_string(const int32 data_type);

#endif /* HDF_FILE_H */
