/*...............................................................................
 
  DESCRIPTION:
 
        This module contains some usual system includes and various definitions and declarations.
 
  TEAM_UNIQUE HEADER:

        Equipe Interaction Rayonnement Nuages
        Laboratoire d'Optique Atmospherique
        Universite des Sciences et Technologies de Lille, Villeneuve d'Ascq
 
  PROGRAMMERS:

        Jerome Riedi  (jerome dot riedi at univ-lille1 dot fr)
        Francois Thieuleux (francois dot thieuleux at univ-lille1 dot fr)
 
  REFERENCES AND CREDITS

        This work has been supported by USTL, CNRS and CNES.
        All credits go to Laboratoire d'Optique Atmospherique (USTL)
 
 ...............................................................................*/
/* --
Copyright (c) 2004-2012 by 

Jerome Riedi (jerome dot riedi at univ-lille1 dot fr)
Francois Thieuleux (francois dot thieuleux at univ-lille1 dot fr)

Laboratoire d'Optique Atmospherique
Batiment P5, USTL
59 655 Villeneuve d'Ascq Cedex
FRANCE
http://www-loa.univ-lille1.fr


This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

-- */
#ifndef COMMON_SYSTEM_H
#define COMMON_SYSTEM_H

/**
* @defgroup common_var  Module common_system
* \brief Commons systems variables
*/
//@{

#include <unistd.h>

#ifndef STDIN_FILENO
# define STDIN_FILENO 0
#endif

#ifndef STDOUT_FILENO
# define STDOUT_FILENO 1
#endif

#ifndef STDERR_FILENO
# define STDERR_FILENO 2
#endif


//#define _(msgid) gettext (msgid)

/* By default, colon separates directories in a path.  */
#ifndef PATH_SEPARATOR
#define PATH_SEPARATOR ':'
#endif

/* These should be phased out in favor of IS_DIR_SEPARATOR, where possible.  */
#ifndef DIR_SEPARATOR
# define DIR_SEPARATOR '/'
# ifdef HAVE_DOS_BASED_FILE_SYSTEM
#  define DIR_SEPARATOR_2 '\\'
# endif
#endif

#include <stdbool.h>
#include <stdlib.h>

/* The following test is to work around the gross typo in
   systems like Sony NEWS-OS Release 4.0C, whereby EXIT_FAILURE
   is defined to 0, not 1.  */
#if !EXIT_FAILURE
# undef EXIT_FAILURE
# define EXIT_FAILURE 1
#endif

#ifndef EXIT_SUCCESS
# define EXIT_SUCCESS 0
#endif

/* If we don't have an overriding definition, set SUCCESS_EXIT_CODE and
   FATAL_EXIT_CODE to EXIT_SUCCESS and EXIT_FAILURE respectively,
   or 0 and 1 if those macros are not defined.  */
#ifndef SUCCESS_EXIT_CODE
# ifdef EXIT_SUCCESS
#  define SUCCESS_EXIT_CODE EXIT_SUCCESS
# else
#  define SUCCESS_EXIT_CODE 0
# endif
#endif

#ifndef FATAL_EXIT_CODE
# ifdef EXIT_FAILURE
#  define FATAL_EXIT_CODE EXIT_FAILURE
# else
#  define FATAL_EXIT_CODE 1
# endif
#endif

/* limits.h must come before pathmax.h because limits.h on some systems
    undefs PATH_MAX, whereas pathmax.h sets PATH_MAX.  */
#include <limits.h>

#include "common/pathmax.h"

#ifndef PATH_MAX
# define PATH_MAX        4096	/* # chars in a path name including nul */
#endif


#ifndef CHAR_MIN
# define CHAR_MIN TYPE_MINIMUM (char)
#endif

#ifndef CHAR_MAX
# define CHAR_MAX TYPE_MAXIMUM (char)
#endif

/* These enum values cannot possibly conflict with the option values
 *    ordinarily used by commands, including CHAR_MAX + 1, etc.  Avoid
 *       CHAR_MIN - 1, as it may equal -1, the getopt end-of-options value.  */
enum
{
  GETOPT_HELP_CHAR = (CHAR_MIN - 2),
  GETOPT_EXAMPLES_CHAR = (CHAR_MIN - 3),
  GETOPT_VERSION_CHAR = (CHAR_MIN - 4)
};

#include "version-etc.h"

#ifndef MAX
# define MAX(a, b) ((a) > (b) ? (a) : (b))
#endif

#ifndef MIN
# define MIN(a,b) (((a) < (b)) ? (a) : (b))
#endif


//}@

#endif /* COMMON_SYSTEM_H */
